@@ -1,10 +1,10 @@
-from argparse import Namespace
 import logging
 import multiprocessing as mp
 import os
 import sys
 import tempfile
 
+from argparse import Namespace
 from datetime import datetime
 from pathlib import Path
 
@@ -18,6 +18,7 @@ log = logging.getLogger('CONFIG')
 env = os.environ.copy()
 threads = None
 verbose = None
+debug = None
 
 # input / output configuration
 db_path = None
@@ -55,9 +56,11 @@ skip_ncrna = None
 skip_ncrna_region = None
 skip_crispr = None
 skip_cds = None
+skip_pseudo = None
 skip_sorf = None
 skip_gap = None
 skip_ori = None
+skip_plot = None
 
 run_start = datetime.now()
 run_end = None
@@ -66,12 +69,16 @@ run_end = None
 def setup(args):
     """Test environment and build a runtime configuration."""
     # runtime configurations
-    global env, threads, verbose
+    global env, threads, verbose, debug
     env['BLAST_USAGE_REPORT'] = 'false'  # prevent BLAST from contacting NCBI
 
     threads = check_threads(args)
     verbose = args.verbose
     log.info('verbose=%s', verbose)
+    debug = args.debug
+    log.info('debug=%s', debug)
+    if(debug):
+        verbose = True
 
     # input / output path configurations
     global db_path, db_info, tmp_path, genome_path, min_contig_length, prefix, output_path
@@ -205,7 +212,7 @@ def setup(args):
     
 
     # workflow configurations
-    global skip_trna, skip_tmrna, skip_rrna, skip_ncrna, skip_ncrna_region, skip_crispr, skip_cds, skip_sorf, skip_gap, skip_ori
+    global skip_trna, skip_tmrna, skip_rrna, skip_ncrna, skip_ncrna_region, skip_crispr, skip_cds, skip_pseudo, skip_sorf, skip_gap, skip_ori, skip_plot
     skip_trna = args.skip_trna
     log.info('skip-tRNA=%s', skip_trna)
     skip_tmrna = args.skip_tmrna
@@ -220,12 +227,16 @@ def setup(args):
     log.info('skip-CRISPR=%s', skip_crispr)
     skip_cds = args.skip_cds
     log.info('skip-CDS=%s', skip_cds)
+    skip_pseudo = args.skip_pseudo
+    log.info('skip-pseudo=%s', skip_pseudo)
     skip_sorf = args.skip_sorf
     log.info('skip-sORF=%s', skip_sorf)
     skip_gap = args.skip_gap
     log.info('skip-gap=%s', skip_gap)
     skip_ori = args.skip_ori
     log.info('skip-ori=%s', skip_ori)
+    skip_plot = args.skip_plot
+    log.info('skip-plot=%s', skip_plot)
 
 
 def check_readability(file_name: str, file_Path: Path):
@@ -243,12 +254,23 @@ def check_content_size(file_name: str, file_path: Path):
 def check_threads(args: Namespace) -> int:
     global threads
     threads = args.threads
-    if(threads <= 0):
+
+    try:
+        max_threads = len(os.sched_getaffinity(0))
+        log.debug(f"max-threads={max_threads}")
+    except AttributeError:
+        max_threads = mp.cpu_count()
+        log.debug(f"scheduler affinity not availabe! max-threads={max_threads}")
+
+    if(threads == 0):
+        threads = max_threads
+        log.debug("request max threads.")
+    elif(threads < 0):
         log.error("wrong argument for 'threads' parameter! threads=%i", threads)
-        sys.exit(f"ERROR: wrong argument ({threads}) for 'threads' parameter! Value must be larger than 0.")
-    elif(threads > mp.cpu_count()):
-        log.error("wrong argument for 'threads' parameter! More threads requested than available: requested=%i, available=%i", threads, mp.cpu_count())
-        sys.exit(f"ERROR: wrong argument ({threads}) for 'threads' parameter! More threads requested ({threads}) than available ({mp.cpu_count()}).")
+        sys.exit(f"ERROR: wrong argument ({threads}) for 'threads' parameter! Value must be larger than/equal to 0.")
+    elif(threads > max_threads):
+        log.error("wrong argument for 'threads' parameter! More threads requested than available: requested=%i, available=%i", threads, max_threads)
+        sys.exit(f"ERROR: wrong argument ({threads}) for 'threads' parameter! More threads requested ({threads}) than available ({max_threads}).")
     log.info('threads=%i', threads)
     return threads
 
