@@ -10,6 +10,7 @@ RE_INSDC_ID = re.compile(r'[A-Za-z\d_.:*#-]{1,25}')  # https://www.ncbi.nlm.nih.
 RE_LOCUSTAG_PREFIX = re.compile(r'[A-Za-z\d_.-]{1,24}')  # https://ena-docs.readthedocs.io/en/latest/faq/locus_tags.html
 RE_INSDC_LOCUSTAG_PREFIX = re.compile(r'[A-Z][A-Z0-9]{2,11}')  # https://ena-docs.readthedocs.io/en/latest/faq/locus_tags.html
 
+
 ############################################################################
 # sORF prediction setttings
 ############################################################################
@@ -28,6 +29,32 @@ MIN_SORF_IDENTITY = 0.9  # min sORF identity for PSC detection
 HYPOTHETICAL_PROTEIN = 'hypothetical protein'  # hypothetical protein product description
 
 
+############################################################################
+# Pseudogene identification settings
+############################################################################
+MIN_PSEUDOGENE_IDENTITY = 0.8  # min protein identity for pseudogene prediction
+MIN_PSEUDOGENE_QUERY_COVERAGE = 0.8  # min query coverage for pseudogene prediction
+MIN_PSEUDOGENE_SUBJECT_COVERAGE = 0.4  # min subject coverage for pseudogene prediction
+PSEUDOGENE_OFFSET = 300  # nucleotide offset for pseudogene class detection
+
+
+############################################################################
+# Pseudogene feature tags
+############################################################################
+PSEUDOGENE = 'pseudogene'
+PSEUDOGENE_CAUSE_INSERTION = 'insertion'
+PSEUDOGENE_CAUSE_DELETION = 'deletion'
+PSEUDOGENE_CAUSE_MUTATION = 'mutation'
+PSEUDOGENE_EFFECT_START = 'start'
+PSEUDOGENE_EFFECT_START_GAIN = 'start-gain'
+PSEUDOGENE_EFFECT_START_LOSS = 'start-loss'
+PSEUDOGENE_EFFECT_STOP = 'stop'
+PSEUDOGENE_EFFECT_STOP_GAIN = 'stop-gain'
+PSEUDOGENE_EFFECT_STOP_LOSS = 'stop-loss'
+PSEUDOGENE_EXCEPTION_SELENOCYSTEINE = 'selenocysteine'
+PSEUDOGENE_EXCEPTION_PYROLYSINE = 'pyrolysine'
+
+
 ############################################################################
 # DB identifiers
 ############################################################################
@@ -38,6 +65,7 @@ DB_XREF_REFSEQ_NRP = 'RefSeq'
 DB_XREF_NCBI_PROTEIN = 'NCBIProtein'
 DB_XREF_EC = 'EC'
 DB_XREF_COG = 'COG'
+DB_XREF_KOFAM = 'KEGG'
 DB_XREF_PFAM = 'Pfam'
 DB_XREF_RFAM = 'RFAM'
 DB_XREF_IS = 'IS'
@@ -54,6 +82,7 @@ DB_PREFIX_UNIPARC = 'UPI'  # https://registry.identifiers.org/registry/uniparc
 DB_PREFIX_REFSEQ_NRP = 'WP_'
 DB_PREFIX_GO = 'GO:'  # https://registry.identifiers.org/registry/go
 DB_PREFIX_COG = 'COG'  # https://www.ebi.ac.uk/miriam/main/collections/MIR:00000296
+DB_PREFIX_KEGG_ORTHOLOGY = 'K'
 DB_PREFIX_IS = 'IS'  # https://www.ebi.ac.uk/miriam/main/collections/MIR:00000173
 DB_PREFIX_PFAM = 'PF'  # https://registry.identifiers.org/registry/pfam
 
@@ -78,6 +107,7 @@ FEATURE_ORIT = 'oriT'
 FEATURE_IS = 'is'
 FEATURE_MITE = 'mite'
 
+
 ############################################################################
 # INSDC feature tags
 ############################################################################
@@ -96,6 +126,9 @@ INSDC_FEATURE_REPEAT_TYPE = 'rpt_type'  # /rpt_type=<repeat_type>  # 'direct'
 INSDC_FEATURE_REPEAT_UNIT_RANGE = 'rpt_unit_range'  # /rpt_unit_range=<base_range>
 INSDC_FEATURE_REPEAT_UNIT_SEQ = 'rpt_unit_seq'  # /rpt_unit_seq="text"
 INSDC_FEATURE_CDS = 'CDS'
+INSDC_FEATURE_PSEUDOGENE = 'pseudogene'
+INSDC_FEATURE_PSEUDOGENE_TYPE_UNITARY = 'unitary'
+INSDC_FEATURE_PSEUDOGENE_TYPE_UNPROCESSED = 'unprocessed'
 INSDC_FEATURE_SIGNAL_PEPTIDE = 'sig_peptide'
 INSDC_FEATURE_GAP = 'gap'
 INSDC_FEATURE_ASSEMBLY_GAP = 'assembly_gap'
@@ -118,13 +151,16 @@ INSDC_FEATURE_MOBILE_ELEMENT_TYPE_TRANSPOSON = 'transposon'
 INSDC_FEATURE_MOBILE_ELEMENT_TYPE_ = 'integron'
 INSDC_FEATURE_MOBILE_ELEMENT_TYPE_ = 'other'
 
+
 ############################################################################
 # Feature ends
 ############################################################################
 FEATURE_END_5_PRIME = '5-prime'
 FEATURE_END_3_PRIME = '3-prime'
+FEATURE_END_BOTH = 'both'
 FEATURE_END_UNKNOWN = '?'
 
+
 ############################################################################
 # Strand types prefixes
 ############################################################################
@@ -133,6 +169,7 @@ STRAND_REVERSE = '-'
 STRAND_UNKNOWN = '?'
 STRAND_NA = '.'
 
+
 ############################################################################
 # Gram types
 ############################################################################
@@ -140,30 +177,41 @@ GRAM_POSITIVE = '+'
 GRAM_NEGATIVE = '-'
 GRAM_UNKNOWN = '?'
 
+
 ############################################################################
 # Replicon types, length thresholds & topology
 ############################################################################
 REPLICON_CHROMOSOME = 'chromosome'
 REPLICON_PLASMID = 'plasmid'
 REPLICON_CONTIG = 'contig'
-
 REPLICON_LENGTH_THRESHOLD_PLASMID = 112_000  # Nasuia deltocephalinicola -> DOI: 10.1093/gbe/evt118
 REPLICON_LENGTH_THRESHOLD_CHROMOSOME = 2_800_000  # max plasmid length (except 1 outlier-> https://ccb-microbe.cs.uni-saarland.de/plsdb/plasmids/
-
 TOPOLOGY_CIRCULAR = 'circular'
 TOPOLOGY_LINEAR = 'linear'
 
+
 ############################################################################
-# Miscellaneous constants
+# Plot types
+############################################################################
+PLOT_FEATURES = 'features'
+PLOT_COG = 'cog'
+
+
+############################################################################
+# Discard types
 ############################################################################
 DISCARD_TYPE_SPURIOUS = 'spurious'
 DISCARD_TYPE_OVERLAP = 'overlap'
 DISCARD_TYPE_RECODING = 'recoding'
 
+
+############################################################################
+# Miscellaneous constants
+############################################################################
 DB_VERSIONS_URL = 'https://raw.githubusercontent.com/oschwengers/bakta/master/db-versions.json'
 
 BAKTA_DOI = '10.1099/mgen.0.000685'
 BAKTA_URL = 'github.com/oschwengers/bakta'
 BAKTA_CITATION = f'''Schwengers O., Jelonek L., Dieckmann M. A., Beyvers S., Blom J., Goesmann A. (2021).
 Bakta: rapid and standardized annotation of bacterial genomes via alignment-free sequence identification.
-Microbial Genomics, 7(11). https://doi.org/{BAKTA_DOI}'''
\ No newline at end of file
+Microbial Genomics, 7(11). https://doi.org/{BAKTA_DOI}'''
