@@ -91,12 +91,11 @@ def predict_t_rnas(genome: dict, contigs_path: Path):
             trna['product'] = 'tRNA-Xxx'
             if(trna_type != 'Undet' and trna_type != 'Sup'):
                 trna['gene'] = f'{trna_type}_trna'
-                trna['product'] = f'tRNA-{trna_type}'
+                trna['product'] = f'tRNA-{trna_type}({anti_codon.lower()})'
                 trna['amino_acid'] = trna_type
                 trna['anti_codon'] = anti_codon.lower()
 
             if('pseudo' in note):
-                trna['product'] = f"(pseudo) {trna['product']}"
                 trna['pseudo'] = True
 
             trna['score'] = float(score)
@@ -120,7 +119,6 @@ def predict_t_rnas(genome: dict, contigs_path: Path):
         for record in SeqIO.parse(fh, 'fasta'):
             trna = trnas[record.id]
             nt = str(record.seq).upper()
-            assert trna['nt'] == nt
             if('anti_codon' in trna and trna['amino_acid'].lower() not in ['fmet', 'ile2', 'sec', 'sup']):  # exclude fMet, Ile2 and Sec (INSDC wrong anticodon issue)
                 anticodon_pos = trna['nt'].lower().find(trna['anti_codon'])
                 if(anticodon_pos > -1):
