@@ -62,6 +62,10 @@ def write_gff3(genome: dict, features_by_contig: Dict[str, dict], gff3_path: Pat
                         annotations['gene'] = feat['gene']
                     if(feat.get('pseudo', False)):
                         annotations['pseudo'] = True
+                    if(feat.get('anti_codon', False)):
+                        annotations['anti_codon'] = feat['anti_codon']
+                    if(feat.get('amino_acid', False)):
+                        annotations['amino_acid'] = feat['amino_acid']
                     if(cfg.compliant):
                         gene_id = f"{feat['locus']}_gene"
                         annotations['Parent'] = gene_id
@@ -74,8 +78,8 @@ def write_gff3(genome: dict, features_by_contig: Dict[str, dict], gff3_path: Pat
                         if(feat.get('gene', None)):
                             gene_annotations['gene'] = feat['gene']
                         if(feat.get('pseudo', None)):
-                            annotations['pseudo'] = 'true'
-                            gene_annotations['pseudo'] = 'true'
+                            annotations[bc.INSDC_FEATURE_PSEUDOGENE] = 'true'
+                            gene_annotations[bc.INSDC_FEATURE_PSEUDOGENE] = 'true'
                         gene_annotations = encode_annotations(gene_annotations)
                         fh.write(f"{feat['contig']}\ttRNAscan-SE\tgene\t{start}\t{stop}\t.\t{feat['strand']}\t.\t{gene_annotations}\n")
                     annotations = encode_annotations(annotations)
@@ -115,19 +119,14 @@ def write_gff3(genome: dict, features_by_contig: Dict[str, dict], gff3_path: Pat
                     if(cfg.compliant):
                         gene_id = f"{feat['locus']}_gene"
                         annotations['Parent'] = gene_id
-                        for dbxref in feat['db_xrefs']:
-                            if(dbxref.split(':')[0] == 'RFAM'):
-                                rfam_id = dbxref.split(':')[1]
-                                annotations['inference'] = f'profile:Rfam:{rfam_id}'
+                        for rfam_id in [dbxref.split(':')[1] for dbxref in feat['db_xrefs'] if dbxref.split(':')[0] == bc.DB_XREF_RFAM]:
+                            annotations['inference'] = f'profile:Rfam:{rfam_id}'
                         annotations['Dbxref'], annotations['Note'] = insdc.revise_dbxref_insdc(feat['db_xrefs'])  # remove INSDC invalid DbXrefs
                         gene_annotations = {
                             'ID': gene_id,
                             'locus_tag': feat['locus'],
                             'gene': feat['gene']
                         }
-                        if(feat.get('pseudo', None)):
-                            annotations['pseudo'] = 'true'
-                            gene_annotations['pseudo'] = 'true'
                         gene_annotations = encode_annotations(gene_annotations)
                         fh.write(f"{feat['contig']}\tInfernal\tgene\t{start}\t{stop}\t.\t{feat['strand']}\t.\t{gene_annotations}\n")
                     annotations = encode_annotations(annotations)
@@ -149,10 +148,8 @@ def write_gff3(genome: dict, features_by_contig: Dict[str, dict], gff3_path: Pat
                             'gene': feat['gene']
                         }
                         annotations['Parent'] = gene_id
-                        for dbxref in feat['db_xrefs']:
-                            if(dbxref.split(':')[0] == 'RFAM'):
-                                rfam_id = dbxref.split(':')[1]
-                                annotations['inference'] = f'profile:Rfam:{rfam_id}'
+                        for rfam_id in [dbxref.split(':')[1] for dbxref in feat['db_xrefs'] if dbxref.split(':')[0] == bc.DB_XREF_RFAM]:
+                            annotations['inference'] = f'profile:Rfam:{rfam_id}'
                         annotations['Dbxref'], annotations['Note'] = insdc.revise_dbxref_insdc(feat['db_xrefs'])  # remove INSDC invalid DbXrefs
                         annotations[bc.INSDC_FEATURE_NC_RNA_CLASS] = insdc.select_ncrna_class(feat)
                         gene_annotations = encode_annotations(gene_annotations)
@@ -167,6 +164,8 @@ def write_gff3(genome: dict, features_by_contig: Dict[str, dict], gff3_path: Pat
                         'Dbxref': feat['db_xrefs']
                     }
                     if(cfg.compliant):
+                        for rfam_id in [dbxref.split(':')[1] for dbxref in feat['db_xrefs'] if dbxref.split(':')[0] == bc.DB_XREF_RFAM]:
+                            annotations['inference'] = f'profile:Rfam:{rfam_id}'
                         annotations['Dbxref'], annotations['Note'] = insdc.revise_dbxref_insdc(feat['db_xrefs'])  # remove INSDC invalid DbXrefs
                         annotations[bc.INSDC_FEATURE_REGULATORY_CLASS] = insdc.select_regulatory_class(feat)
                     annotations = encode_annotations(annotations)
@@ -180,6 +179,7 @@ def write_gff3(genome: dict, features_by_contig: Dict[str, dict], gff3_path: Pat
                     feat_type = so.SO_CRISPR.name
                     if(cfg.compliant):
                         feat_type = bc.INSDC_FEATURE_REPEAT_REGION
+                        annotations['inference'] = 'COORDINATES:alignment:pilercr:1.02'
                         annotations['Dbxref'], annotations['Note'] = insdc.revise_dbxref_insdc(feat['db_xrefs'])  # remove INSDC invalid DbXrefs
                         annotations[bc.INSDC_FEATURE_REPEAT_FAMILY] = 'CRISPR'
                         annotations[bc.INSDC_FEATURE_REPEAT_TYPE] = 'direct'
@@ -194,6 +194,8 @@ def write_gff3(genome: dict, features_by_contig: Dict[str, dict], gff3_path: Pat
                         'product': feat['product'],
                         'Dbxref': feat['db_xrefs']
                     }
+                    if(feat.get('pseudo', False)):
+                        annotations['pseudo'] = True
                     if(feat.get('gene', None)):  # add gene annotation if available
                         annotations['gene'] = feat['gene']
                     if(cfg.compliant):
@@ -207,10 +209,12 @@ def write_gff3(genome: dict, features_by_contig: Dict[str, dict], gff3_path: Pat
                         annotations['Parent'] = gene_id
                         annotations['inference'] = 'ab initio prediction:Prodigal:2.6'
                         annotations['Dbxref'], annotations['Note'] = insdc.revise_dbxref_insdc(feat['db_xrefs'])  # remove INSDC invalid DbXrefs
-                        for note in annotations['Note']:
-                            if(bc.DB_XREF_EC in note):
-                                annotations['ec_number'] = note.replace('EC:', '')
-                        annotations['Note'] = [note for note in annotations['Note'] if bc.DB_XREF_EC not in note]
+                        annotations['Note'], ec_number = insdc.extract_ec_from_notes_insdc(annotations, 'Note')
+                        if(feat.get('pseudo', False)):
+                            annotations[bc.INSDC_FEATURE_PSEUDOGENE] = bc.INSDC_FEATURE_PSEUDOGENE_TYPE_UNPROCESSED if feat[bc.PSEUDOGENE]['paralog'] else bc.INSDC_FEATURE_PSEUDOGENE_TYPE_UNITARY
+                            gene_annotations[bc.INSDC_FEATURE_PSEUDOGENE] = bc.INSDC_FEATURE_PSEUDOGENE_TYPE_UNPROCESSED if feat[bc.PSEUDOGENE]['paralog'] else bc.INSDC_FEATURE_PSEUDOGENE_TYPE_UNITARY
+                        if(ec_number is not None):
+                            annotations['ec_number'] = ec_number
                         gene_annotations = encode_annotations(gene_annotations)
                         fh.write(f"{feat['contig']}\tProdigal\tgene\t{start}\t{stop}\t.\t{feat['strand']}\t.\t{gene_annotations}\n")
                     if('exception' in feat):
@@ -248,10 +252,9 @@ def write_gff3(genome: dict, features_by_contig: Dict[str, dict], gff3_path: Pat
                         annotations['Parent'] = gene_id
                         annotations['inference'] = 'ab initio prediction:Bakta'
                         annotations['Dbxref'], annotations['Note'] = insdc.revise_dbxref_insdc(feat['db_xrefs'])  # remove INSDC invalid DbXrefs
-                        for note in annotations['Note']:
-                            if(bc.DB_XREF_EC in note):
-                                annotations['ec_number'] = note.replace('EC:', '')
-                        annotations['Note'] = [note for note in annotations['Note'] if bc.DB_XREF_EC not in note]
+                        annotations['Note'], ec_number = insdc.extract_ec_from_notes_insdc(annotations, 'Note')
+                        if(ec_number is not None):
+                            annotations['ec_number'] = ec_number
                         gene_annotations = encode_annotations(gene_annotations)
                         fh.write(f"{feat['contig']}\tBakta\tgene\t{start}\t{stop}\t.\t{feat['strand']}\t.\t{gene_annotations}\n")
                     annotations = encode_annotations(annotations)
@@ -275,6 +278,7 @@ def write_gff3(genome: dict, features_by_contig: Dict[str, dict], gff3_path: Pat
                         annotations['Note'] = feat['product']
                     else:
                         annotations['product'] = feat['product']
+                        annotations['inference'] = 'similar to DNA sequence'
                     annotations = encode_annotations(annotations)
                     feat_type = bc.INSDC_FEATURE_ORIGIN_REPLICATION if cfg.compliant else so.SO_ORIC.name
                     fh.write(f"{feat['contig']}\tBLAST+\t{feat_type}\t{start}\t{stop}\t.\t{feat['strand']}\t.\t{annotations}\n")
@@ -287,6 +291,7 @@ def write_gff3(genome: dict, features_by_contig: Dict[str, dict], gff3_path: Pat
                         annotations['Note'] = feat['product']
                     else:
                         annotations['product'] = feat['product']
+                        annotations['inference'] = 'similar to DNA sequence'
                     annotations = encode_annotations(annotations)
                     feat_type = bc.INSDC_FEATURE_ORIGIN_REPLICATION if cfg.compliant else so.SO_ORIC.name
                     fh.write(f"{feat['contig']}\tBLAST+\t{feat_type}\t{start}\t{stop}\t.\t{feat['strand']}\t.\t{annotations}\n")
@@ -299,6 +304,7 @@ def write_gff3(genome: dict, features_by_contig: Dict[str, dict], gff3_path: Pat
                         annotations['Note'] = feat['product']
                     else:
                         annotations['product'] = feat['product']
+                        annotations['inference'] = 'similar to DNA sequence'
                     annotations = encode_annotations(annotations)
                     feat_type = bc.INSDC_FEATURE_ORIGIN_TRANSFER if cfg.compliant else so.SO_ORIT.name
                     fh.write(f"{feat['contig']}\tBLAST+\t{feat_type}\t{start}\t{stop}\t.\t{feat['strand']}\t.\t{annotations}\n")
@@ -308,7 +314,6 @@ def write_gff3(genome: dict, features_by_contig: Dict[str, dict], gff3_path: Pat
             for contig in genome['contigs']:  # write sequences
                 fh.write(f">{contig['id']}\n")
                 fh.write(fasta.wrap_sequence(contig['sequence']))
-
     return
 
 
@@ -346,4 +351,4 @@ def write_signal_peptide(fh, feat: dict):
         'Parent': feat['locus']
     }
     annotations = encode_annotations(annotations)
-    fh.write(f"{feat['contig']}\tDeepSig\t{so.SO_SIGNAL_PEPTIDE.name}\t{sig_peptide['start']}\t{sig_peptide['stop']}\t{sig_peptide['score']:.2f}\t{feat['strand']}\t.\t{annotations}\n")
\ No newline at end of file
+    fh.write(f"{feat['contig']}\tDeepSig\t{so.SO_SIGNAL_PEPTIDE.name}\t{sig_peptide['start']}\t{sig_peptide['stop']}\t{sig_peptide['score']:.2f}\t{feat['strand']}\t.\t{annotations}\n")
