@@ -14,13 +14,11 @@ import bakta.config as cfg
 import bakta.constants as bc
 import bakta.so as so
 
-# from bakta.constants import FEATURE_CDS
-
 
 log = logging.getLogger('INSDC')
 
 
-def write_insdc(genome: dict, features:Sequence[dict], genbank_output_path: Path, embl_output_path: Path):
+def write_insdc(genome: dict, features: Sequence[dict], genbank_output_path: Path, embl_output_path: Path):
     log.debug('prepare: genbank=%s, embl=%s', genbank_output_path, embl_output_path)
 
     contig_list = []
@@ -48,6 +46,7 @@ def write_insdc(genome: dict, features:Sequence[dict], genbank_output_path: Path
             f"{'oriCs/oriVs':<30} :: {len([feat for feat in contig_features if feat['type'] == bc.FEATURE_ORIC or feat['type'] == bc.FEATURE_ORIV]):5,}",
             f"{'oriTs':<30} :: {len([feat for feat in contig_features if feat['type'] == bc.FEATURE_ORIT]):5,}",
             f"{'gaps':<30} :: {len([feat for feat in contig_features if feat['type'] == bc.FEATURE_GAP]):5,}",
+            f"{'pseudogenes':<30} :: {len([feat for feat in contig_features if feat['type'] == bc.FEATURE_CDS and bc.PSEUDOGENE in feat]):5,}\n"
         )
         contig_annotations = {
             'molecule_type': 'DNA',
@@ -55,7 +54,7 @@ def write_insdc(genome: dict, features:Sequence[dict], genbank_output_path: Path
             'date': date.today().strftime('%d-%b-%Y').upper(),
             'topology': contig['topology'],
             'data_file_division': 'HGT' if contig['type'] == bc.REPLICON_CONTIG else 'BCT',
-            # 'accession': '*',  # hold back unil EMBL output bug is fixed in BioPython (https://github.com/biopython/biopython/pull/3572)
+            # 'accession': '*',  # hold back until EMBL output bug is fixed in BioPython (https://github.com/biopython/biopython/pull/3572)
             'comment': comment
             # TODO: taxonomy
         }
@@ -126,13 +125,16 @@ def write_insdc(genome: dict, features:Sequence[dict], genbank_output_path: Path
                 if('product' in qualifiers):
                     del qualifiers['product']
             elif(feature['type'] == bc.FEATURE_CDS) or (feature['type'] == bc.FEATURE_SORF):
-                qualifiers['translation'] = feature['aa']
+                if(feature.get('pseudo', False)):
+                    qualifiers[bc.INSDC_FEATURE_PSEUDOGENE] = bc.INSDC_FEATURE_PSEUDOGENE_TYPE_UNPROCESSED if feature[bc.PSEUDOGENE]['paralog'] else bc.INSDC_FEATURE_PSEUDOGENE_TYPE_UNITARY
+                else:
+                    qualifiers['protein_id'] = f"gnl|Bakta|{feature['locus']}"
+                    qualifiers['translation'] = feature['aa']
                 qualifiers['codon_start'] = 1
                 qualifiers['transl_table'] = cfg.translation_table
                 insdc_feature_type = bc.INSDC_FEATURE_CDS
                 inference = []
                 inference.append('ab initio prediction:Prodigal:2.6' if feature['type'] == bc.FEATURE_CDS else f"ab initio prediction:Bakta:{'.'.join(bakta.__version__.split('.')[0:2])}")
-                qualifiers['protein_id'] = f"gnl|Bakta|{feature['locus']}"
                 if('ncbi_nrp_id' in feature.get('ups', {})):
                     nrp_id = feature['ups']['ncbi_nrp_id']
                     inference.append(f'similar to AA sequence:{bc.DB_XREF_REFSEQ_NRP}:{nrp_id}')
@@ -150,10 +152,11 @@ def write_insdc(genome: dict, features:Sequence[dict], genbank_output_path: Path
                     inference.append(f'similar to AA sequence:{bc.DB_XREF_UNIREF}:{pscc_subject_id}')
                 qualifiers['inference'] = inference
                 if(cfg.compliant):
-                    for note in qualifiers['note']:  # move EC numbers from note to EC_number
-                        if(bc.DB_XREF_EC in note):
-                            qualifiers['EC_number'] = note.replace('EC:', '')
-                    qualifiers['note'] = [note for note in qualifiers['note'] if bc.DB_XREF_EC not in note]
+                    qualifiers['note'], ec_number = extract_ec_from_notes_insdc(qualifiers, 'note')
+                    if(ec_number is not None):
+                            qualifiers['EC_number'] = ec_number
+                if(feature.get('pseudo', False)):
+                    qualifiers['note'].append(feature[bc.PSEUDOGENE]['description'])
                 if('exception' in feature):
                     ex = feature['exception']
                     pos = f"{ex['start']}..{ex['stop']}"
@@ -167,7 +170,7 @@ def write_insdc(genome: dict, features:Sequence[dict], genbank_output_path: Path
                     sigpep_qualifiers['inference'] = 'ab initio prediction:DeepSig:1.2'
                     sigpep = feature[bc.FEATURE_SIGNAL_PEPTIDE]
                     sigpep_strand = 1 if feature['strand'] == bc.STRAND_FORWARD else -1 if feature['strand'] == bc.STRAND_REVERSE else 0
-                    sigpep_location = FeatureLocation(sigpep['start'] - 1, sigpep['stop'], strand = sigpep_strand)
+                    sigpep_location = FeatureLocation(sigpep['start'] - 1, sigpep['stop'], strand=sigpep_strand)
                     sigpep_feature = SeqFeature(sigpep_location, type=bc.INSDC_FEATURE_SIGNAL_PEPTIDE, qualifiers=sigpep_qualifiers)
                     accompanying_features.append(sigpep_feature)
             elif(feature['type'] == bc.FEATURE_T_RNA):
@@ -185,24 +188,17 @@ def write_insdc(genome: dict, features:Sequence[dict], genbank_output_path: Path
                 qualifiers['inference'] = 'profile:aragorn:1.2'
                 insdc_feature_type = bc.INSDC_FEATURE_TM_RNA
             elif(feature['type'] == bc.FEATURE_R_RNA):
-                for dbxref in feature['db_xrefs']:
-                    if(dbxref.split(':')[0] == 'RFAM'):
-                        rfam_id = dbxref.split(':')[1]
-                        qualifiers['inference'] = f'profile:Rfam:{rfam_id}'
+                for rfam_id in [dbxref.split(':')[1] for dbxref in feature['db_xrefs'] if dbxref.split(':')[0] == bc.DB_XREF_RFAM]:
+                    qualifiers['inference'] = f'profile:Rfam:{rfam_id}'
                 insdc_feature_type = bc.INSDC_FEATURE_R_RNA
             elif(feature['type'] == bc.FEATURE_NC_RNA):
-                # TODO: ncRNA_class
-                for dbxref in feature['db_xrefs']:
-                    if(dbxref.split(':')[0] == 'RFAM'):
-                        rfam_id = dbxref.split(':')[1]
-                        qualifiers['inference'] = f'profile:Rfam:{rfam_id}'
+                for rfam_id in [dbxref.split(':')[1] for dbxref in feature['db_xrefs'] if dbxref.split(':')[0] == bc.DB_XREF_RFAM]:
+                    qualifiers['inference'] = f'profile:Rfam:{rfam_id}'
                 qualifiers[bc.INSDC_FEATURE_NC_RNA_CLASS] = select_ncrna_class(feature)
                 insdc_feature_type = bc.INSDC_FEATURE_NC_RNA
             elif(feature['type'] == bc.FEATURE_NC_RNA_REGION):
-                for dbxref in feature['db_xrefs']:
-                    if(dbxref.split(':')[0] == 'RFAM'):
-                        rfam_id = dbxref.split(':')[1]
-                        qualifiers['inference'] = f'profile:Rfam:{rfam_id}'
+                for rfam_id in [dbxref.split(':')[1] for dbxref in feature['db_xrefs'] if dbxref.split(':')[0] == bc.DB_XREF_RFAM]:
+                    qualifiers['inference'] = f'profile:Rfam:{rfam_id}'
                 qualifiers[bc.INSDC_FEATURE_REGULATORY_CLASS] = select_regulatory_class(feature)
                 insdc_feature_type = bc.INSDC_FEATURE_REGULATORY
                 qualifiers['note'] = feature['product']
@@ -245,7 +241,7 @@ def write_insdc(genome: dict, features:Sequence[dict], genbank_output_path: Path
                             stop = AfterPosition(stop)
                         else:
                             start = BeforePosition(start)
-                    else:
+                    elif(feature['truncated'] == bc.FEATURE_END_BOTH):
                         start = BeforePosition(start)
                         stop = AfterPosition(stop)
                 feature_location = FeatureLocation(start, stop, strand=strand)
@@ -256,6 +252,8 @@ def write_insdc(genome: dict, features:Sequence[dict], genbank_output_path: Path
                 if(feature.get('gene', None)):
                     qualifiers['gene'] = feature['gene']
                     gene_qualifier['gene'] = feature['gene']
+                if(feature.get(bc.PSEUDOGENE, None)):
+                    gene_qualifier[bc.INSDC_FEATURE_PSEUDOGENE] = bc.INSDC_FEATURE_PSEUDOGENE_TYPE_UNPROCESSED if feature[bc.PSEUDOGENE]['paralog'] else bc.INSDC_FEATURE_PSEUDOGENE_TYPE_UNITARY
                 gen_seqfeat = SeqFeature(feature_location, type='gene', qualifiers=gene_qualifier)
                 seq_feature_list.append(gen_seqfeat)
             feat_seqfeat = SeqFeature(feature_location, type=insdc_feature_type, qualifiers=qualifiers)
@@ -337,3 +335,14 @@ def revise_dbxref_insdc(dbxrefs: Sequence[str]) -> Tuple[Sequence[str], Sequence
         else:
             invalid_dbxrefs.append(dbxref)
     return valid_dbxrefs, invalid_dbxrefs
+
+
+def extract_ec_from_notes_insdc(qualifiers: dict, note_key: str):
+    note_tmp = []
+    ec_number = None
+    for note in qualifiers[note_key]:  # move EC numbers from note to EC_number qualifier
+        if(note.split(':')[0] == bc.DB_XREF_EC):
+            ec_number = note.replace('EC:', '')
+        else:
+            note_tmp.append(note)
+    return note_tmp, ec_number
