@@ -1,10 +1,6 @@
 import atexit
-import argparse
 import logging
-from math import remainder
-import os
 import sys
-import platform as pf
 
 from datetime import datetime
 from pathlib import Path
@@ -38,7 +34,7 @@ import bakta.ups as ups
 import bakta.ips as ips
 import bakta.psc as psc
 import bakta.pscc as pscc
-
+import bakta.plot as plot
 
 def main():
     args = bu.parse_arguments()  # parse arguments
@@ -58,7 +54,6 @@ def main():
     # - test binary dependencies
     ############################################################################
     cfg.setup(args)  # check parameters and prepare global configuration
-    atexit.register(bu.cleanup, log, cfg.tmp_path)  # register cleanup exit hook
     cfg.db_info = db.check(cfg.db_path)
     bu.test_dependencies()
     if(cfg.verbose):
@@ -70,6 +65,7 @@ def main():
         print(f'\tprefix: {cfg.prefix}')
         print(f'\ttmp directory: {cfg.tmp_path}')
         print(f'\t# threads: {cfg.threads}')
+        if(cfg.debug): print(f'\tdebug: {cfg.debug}')
         if(cfg.compliant): print(f'\tINSDC compliant: {cfg.compliant}')
         if(cfg.keep_contig_headers): print(f'\tkeep contig headers: {cfg.keep_contig_headers}')
         if(cfg.locus): print(f'\tlocus prefix: {cfg.locus}')
@@ -90,6 +86,11 @@ def main():
         if(cfg.skip_sorf): print(f'\tskip sORF: {cfg.skip_sorf}')
         if(cfg.skip_gap): print(f'\tskip gap: {cfg.skip_gap}')
         if(cfg.skip_ori): print(f'\tskip oriC/V/T: {cfg.skip_ori}')
+    
+    if(cfg.debug):
+        print(f"\nBakta runs in DEBUG mode! Temporary data will not be destroyed at: {cfg.tmp_path}")
+    else:
+        atexit.register(bu.cleanup, log, cfg.tmp_path)  # register cleanup exit hook
 
     ############################################################################
     # Import genome
@@ -97,7 +98,7 @@ def main():
     # - apply contig length filter
     # - rename contigs
     ############################################################################
-    print('parse genome sequences...')
+    print('\nparse genome sequences...')
     try:
         contigs = fasta.import_contigs(cfg.genome_path)
         log.info('imported sequences=%i', len(contigs))
@@ -273,17 +274,30 @@ def main():
 
             if(cfg.gram != bc.GRAM_UNKNOWN):
                 sig_peptides_found = sig_peptides.search(cdss, cds_aa_path)
-                print(f"\tsignal peptides: {len(sig_peptides_found)}")
+                print(f'\tsignal peptides: {len(sig_peptides_found)}')
 
             print('\tcombine annotations and mark hypotheticals...')
             log.debug('combine CDS annotations')
             for cds in cdss:
                 anno.combine_annotation(cds)  # combine IPS & PSC annotations and mark hypotheticals
 
-            log.debug('analyze hypotheticals')
+            hypotheticals = [cds for cds in cdss if 'hypothetical' in cds and 'edge' not in cds and cds.get('start_type', 'Edge') != 'Edge']
+            if(len(hypotheticals) > 0):
+                if(not cfg.skip_pseudo):
+                    print('\tdetect pseudogenes...')
+                    log.debug('search pseudogene candidates')
+                    pseudo_candidates = feat_cds.predict_pseudo_candidates(hypotheticals)
+                    print(f'\t\tpseudogene candidates: {len(pseudo_candidates)}')
+                    pseudogenes = feat_cds.detect_pseudogenes(pseudo_candidates, cdss, genome) if len(pseudo_candidates) > 0 else []
+                    psc.lookup(pseudogenes, pseudo=True)
+                    pscc.lookup(pseudogenes, pseudo=True)
+                    for pseudogene in pseudogenes:
+                        anno.combine_annotation(pseudogene)
+                    print(f'\t\tfound pseudogenes: {len(pseudogenes)}')
             hypotheticals = [cds for cds in cdss if 'hypothetical' in cds]
             if(len(hypotheticals) > 0):
-                print(f'\tanalyze hypothetical proteins: {len(hypotheticals)}')
+                log.debug('analyze hypotheticals')
+                print(f'analyze hypothetical proteins: {len(hypotheticals)}')
                 pfam_hits = feat_cds.predict_pfam(hypotheticals)
                 print(f"\tdetected Pfam hits: {len(pfam_hits)} ")
                 feat_cds.analyze_proteins(hypotheticals)
@@ -468,6 +482,7 @@ def main():
     cdss = [f for f in features if f['type'] == bc.FEATURE_CDS]
     print(f"\tCDSs: {len(cdss)}")
     print(f"\t  hypotheticals: {len([cds for cds in cdss if 'hypothetical' in cds])}")
+    print(f"\t  pseudogenes: {len([cds for cds in cdss if 'pseudogene' in cds])}")
     print(f"\t  signal peptides: {len([cds for cds in cdss if bc.FEATURE_SIGNAL_PEPTIDE in cds])}")
     print(f"\tsORFs: {len([f for f in features if f['type'] == bc.FEATURE_SORF])}")
     print(f"\tgaps: {len([f for f in features if f['type'] == bc.FEATURE_GAP])}")
@@ -514,6 +529,12 @@ def main():
     faa_path = cfg.output_path.joinpath(f'{cfg.prefix}.faa')
     fasta.write_faa(features, faa_path)
 
+    if(cfg.skip_plot):
+        print('\tskip generation of circular genome plot...')
+    else:
+        print('\tcircular genome plot...')
+        plot.write_plot(features, contigs, cfg.output_path)
+
     if(cfg.skip_cds is False):
         hypotheticals = [feat for feat in features if feat['type'] == bc.FEATURE_CDS and 'hypothetical' in feat]
         print('\thypothetical TSV...')
@@ -546,6 +567,7 @@ def main():
         fh_out.write(f"ncRNA regions: {len([f for f in features if f['type'] == bc.FEATURE_NC_RNA_REGION])}\n")
         fh_out.write(f"CRISPR arrays: {len([f for f in features if f['type'] == bc.FEATURE_CRISPR])}\n")
         fh_out.write(f"CDSs: {len(cdss)}\n")
+        fh_out.write(f"pseudogenes: {len([cds for cds in cdss if 'pseudogene' in cds])}\n")
         fh_out.write(f"hypotheticals: {len([cds for cds in cdss if 'hypothetical' in cds])}\n")
         fh_out.write(f"signal peptides: {len([cds for cds in cdss if bc.FEATURE_SIGNAL_PEPTIDE in cds])}\n")
         fh_out.write(f"sORFs: {len([f for f in features if f['type'] == bc.FEATURE_SORF])}\n")
